==> mysql-8.0.32.tar.gz: mysql-8.0.32/storage/ndb/src/kernel/blocks/RestoreProxy.hpp <==
/* Copyright (c) 2008, 2022, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef NDB_RESTORE_PROXY_HPP
#define NDB_RESTORE_PROXY_HPP

#include <LocalProxy.hpp>

#define JAM_FILE_ID 435


class RestoreProxy : public LocalProxy {
public:
  RestoreProxy(Block_context& ctx);
  ~RestoreProxy() override;
  BLOCK_DEFINES(RestoreProxy);

protected:
  SimulatedBlock* newWorker(Uint32 instanceNo) override;
};


#undef JAM_FILE_ID

#endif

==> mysql-8.4_8.4.4.orig.tar.gz: mysql-8.4.4/storage/ndb/src/kernel/blocks/RestoreProxy.hpp <==
/* Copyright (c) 2008, 2024, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef NDB_RESTORE_PROXY_HPP
#define NDB_RESTORE_PROXY_HPP

#include <LocalProxy.hpp>

#define JAM_FILE_ID 435

class RestoreProxy : public LocalProxy {
 public:
  RestoreProxy(Block_context &ctx);
  ~RestoreProxy() override;
  BLOCK_DEFINES(RestoreProxy);

 protected:
  SimulatedBlock *newWorker(Uint32 instanceNo) override;
};

#undef JAM_FILE_ID

#endif
